==> duckdb_0.3.2.tar.gz: duckdb/src/duckdb/amalgamation-8.cpp <==
#include "src/function/scalar/sequence/nextval.cpp"

#include "src/function/scalar/sequence_functions.cpp"

#include "src/function/scalar/string/ascii.cpp"

#include "src/function/scalar/string/caseconvert.cpp"

#include "src/function/scalar/string/chr.cpp"

#include "src/function/scalar/string/concat.cpp"

#include "src/function/scalar/string/contains.cpp"

#include "src/function/scalar/string/instr.cpp"

#include "src/function/scalar/string/jaccard.cpp"

#include "src/function/scalar/string/left_right.cpp"

#include "src/function/scalar/string/length.cpp"

#include "src/function/scalar/string/levenshtein.cpp"

#include "src/function/scalar/string/like.cpp"

#include "src/function/scalar/string/md5.cpp"

#include "src/function/scalar/string/mismatches.cpp"

#include "src/function/scalar/string/nfc_normalize.cpp"

#include "src/function/scalar/string/pad.cpp"

#include "src/function/scalar/string/prefix.cpp"

#include "src/function/scalar/string/printf.cpp"

#include "src/function/scalar/string/regexp.cpp"

#include "src/function/scalar/string/repeat.cpp"

#include "src/function/scalar/string/replace.cpp"

#include "src/function/scalar/string/reverse.cpp"

#include "src/function/scalar/string/string_split.cpp"

#include "src/function/scalar/string/strip_accents.cpp"

#include "src/function/scalar/string/substring.cpp"

#include "src/function/scalar/string/suffix.cpp"

#include "src/function/scalar/string/trim.cpp"

#include "src/function/scalar/string_functions.cpp"

#include "src/function/scalar/struct/struct_extract.cpp"

#include "src/function/scalar/struct/struct_pack.cpp"

#include "src/function/scalar/system/system_functions.cpp"

#include "src/function/scalar/trigonometrics_functions.cpp"

#include "src/function/scalar/uuid/gen_random.cpp"

#include "src/function/scalar_function.cpp"

#include "src/function/table/arrow.cpp"

#include "src/function/table/checkpoint.cpp"

#include "src/function/table/copy_csv.cpp"

#include "src/function/table/glob.cpp"

#include "src/function/table/pragma_detailed_profiling_output.cpp"

#include "src/function/table/pragma_last_profiling_output.cpp"

#include "src/function/table/range.cpp"

#include "src/function/table/read_csv.cpp"

#include "src/function/table/repeat.cpp"

#include "src/function/table/summary.cpp"

#include "src/function/table/system/duckdb_columns.cpp"

==> duckdb_0.3.4-1.tar.gz: duckdb/src/duckdb/amalgamation-8.cpp <==
#include "src/function/scalar/sequence_functions.cpp"

#include "src/function/scalar/string/ascii.cpp"

#include "src/function/scalar/string/caseconvert.cpp"

#include "src/function/scalar/string/chr.cpp"

#include "src/function/scalar/string/concat.cpp"

#include "src/function/scalar/string/contains.cpp"

#include "src/function/scalar/string/instr.cpp"

#include "src/function/scalar/string/jaccard.cpp"

#include "src/function/scalar/string/left_right.cpp"

#include "src/function/scalar/string/length.cpp"

#include "src/function/scalar/string/levenshtein.cpp"

#include "src/function/scalar/string/like.cpp"

#include "src/function/scalar/string/md5.cpp"

#include "src/function/scalar/string/mismatches.cpp"

#include "src/function/scalar/string/nfc_normalize.cpp"

#include "src/function/scalar/string/pad.cpp"

#include "src/function/scalar/string/prefix.cpp"

#include "src/function/scalar/string/printf.cpp"

#include "src/function/scalar/string/regexp.cpp"

#include "src/function/scalar/string/repeat.cpp"

#include "src/function/scalar/string/replace.cpp"

#include "src/function/scalar/string/reverse.cpp"

#include "src/function/scalar/string/string_split.cpp"

#include "src/function/scalar/string/strip_accents.cpp"

#include "src/function/scalar/string/substring.cpp"

#include "src/function/scalar/string/suffix.cpp"

#include "src/function/scalar/string/trim.cpp"

#include "src/function/scalar/string_functions.cpp"

#include "src/function/scalar/struct/struct_extract.cpp"

#include "src/function/scalar/struct/struct_pack.cpp"

#include "src/function/scalar/system/aggregate_export.cpp"

#include "src/function/scalar/system/system_functions.cpp"

#include "src/function/scalar/trigonometrics_functions.cpp"

#include "src/function/scalar/uuid/gen_random.cpp"

#include "src/function/scalar_function.cpp"

#include "src/function/scalar_macro_function.cpp"

#include "src/function/table/arrow.cpp"

#include "src/function/table/checkpoint.cpp"

#include "src/function/table/copy_csv.cpp"

#include "src/function/table/glob.cpp"

#include "src/function/table/pragma_detailed_profiling_output.cpp"

#include "src/function/table/pragma_last_profiling_output.cpp"

#include "src/function/table/range.cpp"

#include "src/function/table/read_csv.cpp"

#include "src/function/table/repeat.cpp"

#include "src/function/table/summary.cpp"

#include "src/function/table/system/duckdb_columns.cpp"
